/*
 For more information, please see: http://software.sci.utah.edu

 The MIT License

 Copyright (c) 2009 Scientific Computing and Imaging Institute,
 University of Utah.


 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
 to deal in the Software without restriction, including without limitation
 the rights to use, copy, modify, merge, publish, distribute, sublicense,
 and/or sell copies of the Software, and to permit persons to whom the
 Software is furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included
 in all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 */

#ifndef QTUTILS_WIDGETS_QTTRANSFERFUNCTIONSCENE_H
#define QTUTILS_WIDGETS_QTTRANSFERFUNCTIONSCENE_H

#include <QGraphicsScene>

#include <Core/Utils/ConnectionHandler.h>

namespace QtUtils
{

class QtTransferFunctionScenePrivate;
class QtTransferFunctionCurve;

class QtTransferFunctionScene : public QGraphicsScene, private Core::ConnectionHandler
{
	Q_OBJECT
public:
	explicit QtTransferFunctionScene( QObject *parent = 0 );
	~QtTransferFunctionScene();

	void add_curve( QtTransferFunctionCurve* curve );
	void delete_curve( const std::string& feature_id );
	QtTransferFunctionCurve* get_active_curve();
	QtTransferFunctionCurve* get_curve( const std::string& feature_id );

protected:
	virtual void mouseMoveEvent( QGraphicsSceneMouseEvent* mouseEvent );
	virtual void mousePressEvent( QGraphicsSceneMouseEvent* mouseEvent );
	virtual void mouseReleaseEvent( QGraphicsSceneMouseEvent* mouseEvent );

public Q_SLOTS:
	void set_view_transform( const QTransform& matrix );

private:
	friend class QtTransferFunctionScenePrivate;
	void reset();

private:
	QtTransferFunctionScenePrivate* private_;

};

} // end namespace QtUtils

#endif // QTTRANSFERFUNCTIONSCENE_H
